| bandwidth | R Documentation |
The kernel bandwidth used by mean shift to estimate the local density gradient. Smaller values yield more clusters, while larger values merge them.
bandwidth(range = c(0.01, 1), trans = NULL)
range |
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units. |
trans |
A |
Used in tidyclust::mean_shift() models. The scale on which the bandwidth
is interpreted depends on the engine, since some engines rescale predictors
internally before applying the kernel.
A dials parameter object for use with tune::tune_grid() and
related functions.
bandwidth()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.