cluster_metric_set() allows you to combine multiple metric functions
together into a new function that calculates all of them at once.
Arguments
- ...
The bare names of the functions to be included in the metric set. These functions must be cluster metrics such as
sse_total(),sse_ratio(), orsilhouette_avg().
Details
All functions must be cluster metrics. To include a metric that
wraps a built-in metric with custom arguments, such as silhouette_avg()
with a non-default dist_fun, first wrap it with new_cluster_metric() so
that it carries the cluster_metric class. See the examples in
new_cluster_metric().