Skip to content

db_clust() creates DBSCAN model.

Details

For this engine, there is a single mode: partition

Tuning Parameters

This model has 2 tuning parameters:

  • radius: Radius (type: double, default: no default)

  • min_points: Minimum Number of Points (type: integer, default: no_default)

Translation from tidyclust to the original package (partition)

db_clust(radius = 0.5, min_points = 5)%>%
  set_engine("dbscan") %>%
  set_mode("partition") %>%
  translate_tidyclust()

## DBSCAN Clustering Specification (partition)
##
## Main Arguments:
##   radius = 0.5
##   min_points = 5
##
## Computational engine: dbscan
##
## Model fit template:
## tidyclust::.db_clust_fit_dbscan(x = missing_arg(), radius = missing_arg(),
##     min_points = missing_arg(), radius = 0.5, min_points = 5)

Preprocessing requirements

Factor/categorical predictors need to be converted to numeric values (e.g., dummy or indicator variables) for this engine. When using the formula method via fit(), tidyclust will convert factor columns to indicators.

Predictors should have the same scale. One way to achieve this is to center and scale each so that each predictor has mean zero and a variance of one.

References