| details_gm_clust_mclust | R Documentation |
gm_clust() creates GMM model.
For this engine, there is a single mode: partition
This model has 6 tuning parameters:
num_clusters: # Clusters (type: integer, default: no default)
circular: Circular MVG (type: logical, default: TRUE)
zero_covariance: Zero Covariance (type: logical, default: TRUE)
shared_orientation: Shared Orientation (type: logical, default:
TRUE)
shared_shape: Shared Shape (type: logical, default: TRUE)
shared_size: Shared Size (type: logical, default: TRUE)
gm_clust(num_clusters = 3, circular = FALSE, zero_covariance = FALSE) %>%
set_engine("mclust") %>%
set_mode("partition") %>%
translate_tidyclust()
## GMM Clustering Specification (partition) ## ## Main Arguments: ## num_clusters = 3 ## circular = FALSE ## zero_covariance = FALSE ## shared_orientation = TRUE ## shared_shape = TRUE ## shared_size = TRUE ## ## Computational engine: mclust ## ## Model fit template: ## tidyclust::.gm_clust_fit_mclust(x = missing_arg(), num_clusters = missing_arg(), ## circular = missing_arg(), zero_covariance = missing_arg(), ## shared_orientation = missing_arg(), shared_shape = missing_arg(), ## shared_size = missing_arg(), num_clusters = 3, circular = FALSE, ## zero_covariance = FALSE, shared_orientation = TRUE, shared_shape = TRUE, ## shared_size = TRUE)
Gaussian Mixture Models should be fit with only quantitative predictors and without any categorical predictors. No scaling is required since the variance-covariance matrices of the Gaussian distributions account for the unequal variances between predictors and their covariances.
Banfield, J. D., & Raftery, A. E. (1993). Model-Based Gaussian and Non-Gaussian Clustering. Biometrics, 49(3), 803. doi: 10.2307/2532201
Celeux, G., & Govaert, G. (1995). Gaussian parsimonious clustering models. Pattern Recognition, 28(5), 781–793. doi: 10.1016/0031-3203(94)00125-6
Dempster, A. P., Laird, N. M., & Rubin, D. B. (1977). Maximum Likelihood from Incomplete Data via the EM Algorithm.
McNicholas, P. D. (2016). Model-Based clustering. Journal of Classification, 33(3), 331–373. https://link.springer.com/article/10.1007/s00357-016-9211-9
Scrucca, L., Fop, M., Murphy, T., Brendan, & Raftery, A., E. (2016). Mclust 5: Clustering, Classification and Density Estimation Using Gaussian Finite Mixture Models. The R Journal, 8(1), 289. https://journal.r-project.org/articles/RJ-2016-021/index.html
Scrucca, L., Fraley, C., Murphy, T. B., & Raftery, A. E. (2023). Model-based clustering, classification, and density estimation using mclust in R. Chapman; Hall/CRC. https: //doi.org/10.1201/9781003277965
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.