dot-db_clust_fit_dbscan: Simple Wrapper around dbscan function

.db_clust_fit_dbscanR Documentation

Simple Wrapper around dbscan function

Description

This wrapper prepares the data into a distance matrix to send to dbscan::dbscan() and retains the parameters radius or min_points as an attribute.

Usage

.db_clust_fit_dbscan(x, radius = NULL, min_points = NULL, ...)

Arguments

x

matrix or data frame.

radius

Radius used to determine core-points and cluster points together.

min_points

Minimum number of points needed to form a cluster.

Value

dbscan object


tidyclust documentation built on June 20, 2026, 9:08 a.m.