dot-db_clust_fit_hdbscan: Simple Wrapper around hdbscan function

.db_clust_fit_hdbscanR Documentation

Simple Wrapper around hdbscan function

Description

This wrapper passes the data to dbscan::hdbscan() and stashes the training data on the result so it can be reused for prediction and extraction.

Usage

.db_clust_fit_hdbscan(x, min_points = NULL, min_cluster_size = NULL, ...)

Arguments

x

matrix or data frame.

min_points

Minimum cluster size used as the minPts argument of dbscan::hdbscan().

min_cluster_size

Engine-specific override for minPts. When supplied, it is used in place of min_points.

Value

hdbscan object


tidyclust documentation built on June 20, 2026, 9:08 a.m.