dot-mean_shift_fit_meanShiftR: Simple Wrapper around meanShiftR::meanShift function

.mean_shift_fit_meanShiftRR Documentation

Simple Wrapper around meanShiftR::meanShift function

Description

This wrapper passes the data and bandwidth to meanShiftR::meanShift() and stashes the training data and bandwidth on the result so they can be reused for prediction and extraction.

Usage

.mean_shift_fit_meanShiftR(x, bandwidth = NULL, ...)

Arguments

x

matrix or data frame.

bandwidth

Kernel bandwidth controlling the neighborhood size. A scalar is recycled to a per-column vector.

Value

A list with class "ms_meanShiftR".


tidyclust documentation built on June 20, 2026, 9:08 a.m.