new_cluster_spec: Functions required for tidyclust-adjacent packages

View source: R/cluster_spec.R

new_cluster_specR Documentation

Functions required for tidyclust-adjacent packages

Description

These functions are helpful when creating new packages that will register new cluster specifications.

Usage

new_cluster_spec(cls, args, eng_args, mode, method, engine)

Arguments

cls

A single character string for the model type (e.g. "k_means").

args

A named list of main model arguments.

eng_args

A named list of engine-specific arguments.

mode

A single character string for the model mode (e.g. "partition").

method

A list of method details or NULL.

engine

A single character string for the computational engine.

Value

A cluster_spec object made to work with tidyclust.


tidyclust documentation built on June 20, 2026, 9:08 a.m.