radius: Radius

View source: R/dials-params.R

radiusR Documentation

Radius

Description

The radius used by density-based clustering to determine core points and cluster assignments. Used in tidyclust::db_clust() with the dbscan engine.

Usage

radius(range = c(0, dials::unknown()), trans = NULL)

Arguments

range

A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units.

trans

A trans object from the scales package, such as scales::transform_log10() or scales::transform_reciprocal(). If not provided, the default is used which matches the units used in range. If no transformation, NULL.

Value

A dials parameter object for use with tune::tune_grid() and related functions.

Examples

radius()

tidyclust documentation built on June 20, 2026, 9:08 a.m.