| axe-cluster_fit | R Documentation |
cluster_fit objects are created from the tidyclust package.
axe_call.cluster_fit(x, verbose = FALSE, ...)
axe_ctrl.cluster_fit(x, verbose = FALSE, ...)
axe_data.cluster_fit(x, verbose = FALSE, ...)
axe_env.cluster_fit(x, verbose = FALSE, ...)
axe_fitted.cluster_fit(x, verbose = FALSE, ...)
x |
A model object. |
verbose |
Print information each time an axe method is executed.
Notes how much memory is released and what functions are
disabled. Default is |
... |
Any additional arguments related to axing. |
Axed cluster_fit object.
k_fit <- k_means(num_clusters = 3) |>
parsnip::set_engine("stats") |>
fit(~., data = mtcars)
butcher::butcher(k_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.