| contr_one_hot | R Documentation |
A re-export of hardhat::contr_one_hot() for use with
indicators = "one_hot".
contr_one_hot(n, contrasts = TRUE, sparse = FALSE)
n |
A vector of character factor levels (of length >=1) or the number of unique levels (>= 1). |
contrasts |
This argument is for backwards compatibility and only the
default of |
sparse |
This argument is for backwards compatibility and only the
default of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.