| control_cluster | R Documentation |
Options can be passed to the fit.cluster_spec() function that control the
output and computations.
control_cluster(verbosity = 1L, catch = FALSE)
## S3 method for class 'control_cluster'
print(x, ...)
verbosity |
An integer where a value of zero indicates that no messages
or output should be shown when packages are loaded or when the model is
fit. A value of 1 means that package loading is quiet but model fits can
produce output to the screen (depending on if they contain their own
|
catch |
A logical where a value of |
x |
A |
... |
Not currently used. |
An S3 object with class "control_cluster" that is a named list with the results of the function call
The input x, invisibly.
control_cluster()
# Catch errors instead of stopping — useful inside loops or tune_cluster()
control_cluster(catch = TRUE)
# Suppress all output during fitting
control_cluster(verbosity = 0L)
# Show model output but suppress package loading messages (default)
control_cluster(verbosity = 1L)
# Show all output including package loading messages
control_cluster(verbosity = 2L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.