Skip to content

db_clust() creates an HDBSCAN model.

Details

For this engine, there is a single mode: partition

Tuning Parameters

This model has 1 tuning parameters:

  • min_points: Minimum Number of Points (type: integer, default: no default)

The hdbscan engine also accepts the engine-specific argument min_cluster_size (passed via set_engine("hdbscan", min_cluster_size = ...)). When supplied, it overrides min_points as the value of minPts passed to dbscan::hdbscan(). If not supplied, min_points is used.

Translation from tidyclust to the original package (partition)

db_clust(min_points = 5) |>
  set_engine("hdbscan") |>
  set_mode("partition") |>
  translate_tidyclust()

## DBSCAN Clustering Specification (partition)
##
## Main Arguments:
##   min_points = 5
##
## Computational engine: hdbscan
##
## Model fit template:
## tidyclust::.db_clust_fit_hdbscan(x = missing_arg(), min_points = missing_arg(),
##     min_points = 5)

Preprocessing requirements

Factor/categorical predictors need to be converted to numeric values (e.g., dummy or indicator variables) for this engine. When using the formula method via fit(), tidyclust will convert factor columns to indicators.

Predictors should have the same scale. One way to achieve this is to center and scale each so that each predictor has mean zero and a variance of one.

What does it mean to predict?

To predict the cluster assignment for a new observation, the nearest training observation that was not classified as noise is found. The new observation is assigned to that neighbor’s cluster if the distance is at most the neighbor’s core distance; otherwise the new observation is marked as an outlier.

References