Skip to content

gm_clust() creates GMM model.

Details

For this engine, there is a single mode: partition

Tuning Parameters

This model has 6 tuning parameters:

  • num_clusters: # Clusters (type: integer, default: no default)

  • circular: Circular MVG (type: logical, default: TRUE)

  • zero_covariance: Zero Covariance (type: logical, default: TRUE)

  • shared_orientation: Shared Orientation (type: logical, default: TRUE)

  • shared_shape: Shared Shape (type: logical, default: TRUE)

  • shared_size: Shared Size (type: logical, default: TRUE)

Translation from tidyclust to the original package (partition)

gm_clust(num_clusters = 3, circular = FALSE, zero_covariance = FALSE) %>%
  set_engine("mclust") %>%
  set_mode("partition") %>%
  translate_tidyclust()

## GMM Clustering Specification (partition)
##
## Main Arguments:
##   num_clusters = 3
##   circular = FALSE
##   zero_covariance = FALSE
##   shared_orientation = TRUE
##   shared_shape = TRUE
##   shared_size = TRUE
##
## Computational engine: mclust
##
## Model fit template:
## tidyclust::.gm_clust_fit_mclust(x = missing_arg(), num_clusters = missing_arg(),
##     circular = missing_arg(), zero_covariance = missing_arg(),
##     shared_orientation = missing_arg(), shared_shape = missing_arg(),
##     shared_size = missing_arg(), num_clusters = 3, circular = FALSE,
##     zero_covariance = FALSE, shared_orientation = TRUE, shared_shape = TRUE,
##     shared_size = TRUE)

Preprocessing requirements

Gaussian Mixture Models should be fit with only quantitative predictors and without any categorical predictors. No scaling is required since the variance-covariance matrices of the Gaussian distributions account for the unequal variances between predictors and their covariances.

References