| .mean_shift_fit_meanShiftR | R Documentation |
This wrapper passes the data and bandwidth to meanShiftR::meanShift() and
stashes the training data and bandwidth on the result so they can be reused
for prediction and extraction.
.mean_shift_fit_meanShiftR(x, bandwidth = NULL, ...)
x |
matrix or data frame. |
bandwidth |
Kernel bandwidth controlling the neighborhood size. A scalar is recycled to a per-column vector. |
A list with class "ms_meanShiftR".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.