These functions are deprecated. Please use tune::finalize_model() and
tune::finalize_workflow() instead, which now support cluster_spec
objects natively.
Arguments
- x
A recipe,
parsnipmodel specification, or workflow.- parameters
A list or 1-row tibble of parameter values. Note that the column names of the tibble should be the
idfields attached totune(). For example, in theExamplessection below, the model hastune("K"). In this case, the parameter tibble should be "K" and not "neighbors".
Examples
kmeans_spec <- k_means(num_clusters = tune())
best_params <- data.frame(num_clusters = 5)
# Old:
finalize_model_tidyclust(kmeans_spec, best_params)
#> Warning: `finalize_model_tidyclust()` was deprecated in tidyclust 0.3.0.
#> ℹ Please use `tune::finalize_model()` instead.
#> K Means Cluster Specification (partition)
#>
#> Main Arguments:
#> num_clusters = 5
#>
#> Computational engine: stats
#>
# New:
tune::finalize_model(kmeans_spec, best_params)
#> K Means Cluster Specification (partition)
#>
#> Main Arguments:
#> num_clusters = 5
#>
#> Computational engine: stats
#>