| glance.cluster_fit | R Documentation |
This method glances the model in a tidyclust model object, if it exists.
## S3 method for class 'cluster_fit'
glance(x, ...)
x |
model or other R object to convert to single-row data frame |
... |
other arguments passed to methods |
A one-row tibble with model-level summary statistics such as total within-cluster sum of squares, between-cluster sum of squares, and number of iterations. Support depends on the underlying engine.
# glance() support depends on the underlying engine.
## Not run:
kmeans_fit <- k_means(num_clusters = 3) |>
set_engine("stats") |>
fit(~., mtcars)
glance(kmeans_fit)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.