| gm_clust | R Documentation |
gm_clust defines a model that fits clusters based on fitting a specified number of
multivariate Gaussian distributions (MVG) to the data.
There are multiple implementations for this model, and the implementation is chosen by setting the model engine. The engine-specific pages for this model are listed below.
mclust
gm_clust(
mode = "partition",
engine = "mclust",
num_clusters = NULL,
circular = TRUE,
shared_size = TRUE,
zero_covariance = TRUE,
shared_orientation = TRUE,
shared_shape = TRUE
)
mode |
A single character string for the type of model. The only possible value for this model is "partition". |
engine |
A single character string specifying what computational engine
to use for fitting. The engine for this model is |
num_clusters |
Positive integer, number of clusters in model (required). |
circular |
Boolean, whether or not to fit circular MVG distributions for each cluster. Default |
shared_size |
Boolean, whether each cluster MVG should have the same size/volume. Default |
zero_covariance |
Boolean, whether or not to assign covariances of 0 for each MVG. Default |
shared_orientation |
Boolean, whether each cluster MVG should have the same orientation. Default |
shared_shape |
Boolean, whether each cluster MVG should have the same shape. Default |
To predict the cluster assignment for a new observation, we determine which cluster a point has the highest probability of belonging to.
A gm_clust cluster specification.
# Show all engines
modelenv::get_from_env("gm_clust")
gm_clust()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.