Skip to content

The minimum number of connected points required to form a core point in density-based clustering. Used in tidyclust::db_clust() with the dbscan and hdbscan engines.

Usage

min_points(range = c(2L, 20L), trans = NULL)

Arguments

range

A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units.

trans

A trans object from the scales package, such as scales::transform_log10() or scales::transform_reciprocal(). If not provided, the default is used which matches the units used in range. If no transformation, NULL.

Value

A dials parameter object for use with tune::tune_grid() and related functions.

Examples

min_points()
#> Minimum Number of Points (quantitative)
#> Range: [2, 20]