| new_cluster_spec | R Documentation |
These functions are helpful when creating new packages that will register new cluster specifications.
new_cluster_spec(cls, args, eng_args, mode, method, engine)
cls |
A single character string for the model type (e.g. |
args |
A named list of main model arguments. |
eng_args |
A named list of engine-specific arguments. |
mode |
A single character string for the model mode (e.g.
|
method |
A list of method details or |
engine |
A single character string for the computational engine. |
A cluster_spec object made to work with tidyclust.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.