| radius | R Documentation |
The radius used by density-based clustering to determine core points and
cluster assignments. Used in tidyclust::db_clust() with the dbscan
engine.
radius(range = c(0, dials::unknown()), trans = NULL)
range |
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units. |
trans |
A |
A dials parameter object for use with tune::tune_grid() and
related functions.
radius()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.