The radius used by density-based clustering to determine core points and
cluster assignments. Used in tidyclust::db_clust() with the dbscan
engine.
Arguments
- range
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units.
- trans
A
transobject from thescalespackage, such asscales::transform_log10()orscales::transform_reciprocal(). If not provided, the default is used which matches the units used inrange. If no transformation,NULL.
Value
A dials parameter object for use with tune::tune_grid() and
related functions.